@@ -12,6 +12,7 @@ pages = [
         "interfaces/Ensembles.md",
         "interfaces/Common_Keywords.md",
         "interfaces/Differentiation.md",
-        "interfaces/PDE.md"],
-    "Fundamentals" => Any["fundamentals/FAQ.md"]
+        "interfaces/PDE.md",
+    ],
+    "Fundamentals" => Any["fundamentals/FAQ.md"],
 ]
